//importing nessary packages from D3 
import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';
// declaring variables 
const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => { //to explain
  const title = 'Iphone Sales from 2015 to 2021';
  
  const xValue = d => d.Year; //display dates for x axis
  const xAxisLabel = 'Year';
// assigning data for plotting yaxis dataset
  const yValue = d => d.Sales;
  const yAxisLabel = 'Sales';
  
  const margin = { top: 50, right: 50, bottom: 100, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  //container
  
  const xScale = scaleTime()
  //complete set of values for xscale
    .domain(extent(data, xValue)) //returns the minimum and maximum value in an array from the given array using natural order.
    .range([0, innerWidth]) //output bounds
     .nice(0);//round values out
  
  const yScale = scaleLinear()
  //complete set of values for yscale
    .domain([0, max(data, yValue )])//returns the minimum and maximum value in an array from the given array using natural order.
    .range([innerHeight, 0])//output bounds
  	.nice();//round values out
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);//center g in svg
  // assigning xscale dimensions
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(20);
  // assigning yscale dimensions
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
 // assigning label for yaxis 
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -90)
      .attr('x', -innerHeight / 3)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  // assigning label for xaxis
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d))); //coordinates in pixels
  
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
    console.log(lineGenerator(data))
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};
// imporing csv data from github gist
csv('https://gist.githubusercontent.com/Radhakrishna246/ab0a9fd97eb1f3542b7e736862850cd9/raw/ca8aa5f6fe0b9d95509e0d5f4f5eb815f2e2b570/iphonesales.csv')
  .then(data => {
  	//console.log(data)
    data.forEach(d => {
    	d.Sales = +d.Sales;
      d.Year = new Date(d.Year)
    });
  console.log(data)
    render(data);
  });